@@ -1,10 +1,10 @@
 package Devel::LeakTrace;
 use strict;
-require 5.006;
+require 5.008;
 use base 'DynaLoader';
 
 BEGIN {
-    our $VERSION = 0.05;
+    our $VERSION = '0.06';
     bootstrap Devel::LeakTrace $VERSION;
     hook_runops();
 }
@@ -49,7 +49,7 @@ implicit BEGIN blocks of C<use> statements.
 
 =head1 CAVEATS
 
-L<glib|http://developer.gnome.org/doc/API/glib/index.html> is used for
+L<glib|http://developer.gnome.org/glib/> is used for
 it's hash manipulation routines to keep state.  This is an external
 dependency that is hoped can be removed, but tuits as yet haven't
 presented themselves.
